# QuOCS: The optimization library
QuOCS (Quantum Optimal Control Suite) is a python software package for theoretical and experimental optimizations.
You can find here the core of the optimization algorithms used in the QuOCS - suite.

## Unittesting

[![Build Status](https://github.com/Quantum-OCS/QuOCS/actions/workflows/unit_testing_linux.yml/badge.svg)](https://github.com/Quantum-OCS/QuOCS/actions)
[![Build Status](https://github.com/Quantum-OCS/QuOCS/actions/workflows/unit_testing_windows.yml/badge.svg)](https://github.com/Quantum-OCS/QuOCS/actions)
[![Build Status](https://github.com/Quantum-OCS/QuOCS/actions/workflows/python_publish_PyPI.yml/badge.svg)](https://github.com/Quantum-OCS/QuOCS/actions)

## Installation

You can install QuOCS by doing

~~~bash
pip install quocs-lib
~~~

If you want to change the files and adapt algorithms and search methods, you can install it in a folder you like and in the editable mode by downloading from Git and running

~~~bash
pip install -e .
~~~

in that folder.


## Documentation 
https://quantum-ocs.github.io/QuOCS


## Tests
Now you are able to use the tests scripts in the tests folder :)

